﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Navigation;
using MVVMTutorial.Web.Models;
using MVVMTutorial.Helpers;


namespace MVVMTutorial.Views
{
    public partial class LoginPage : Page
    {
        User usr;
        ValidationModel validationModel;
        LoginProxy.LoginServiceClient client;

        public LoginPage()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(LoginPage_Loaded);
        }


        void LoginPage_Loaded(object sender, RoutedEventArgs e)
        {
            this.usr = new User();
            this.validationModel = new ValidationModel();
            this.DataContext = this.usr;
            this.lbValidationCode.DataContext=this.tbValidationCode.DataContext 
                = this.txtValidationCode.DataContext = this.validationModel;

            if (this.NeedInitializeClient())
            {
                this.InitializeClient();
            }
            this.client.GenerateValidationCodeAsync();
        }

        private void btnChangeValidationCode_Click(object sender, RoutedEventArgs e)
        {
            if (this.NeedInitializeClient())
            {
                this.InitializeClient();
            }
            this.client.GenerateValidationCodeAsync();
        }

        private void btnLogin_Click(object sender, RoutedEventArgs e)
        {
            if (this.validationSummary1.HasErrors)
            {
                this.validationSummary1.Focus();
                return;
            }
            else
            {
                // 扩展方法，校验各个控件的数据绑定
                this.LayoutRoot.Children.ValidateSource();
                if (this.validationSummary1.HasErrors)
                {
                    this.validationSummary1.Focus();
                    return;
                }
            }

            if (this.NeedInitializeClient())
            {
                this.InitializeClient();
            }
            this.client.LoginAsync(this.usr , this.validationModel.Code);
        }

        /// <summary>
        /// 检查是否要初始化代理
        /// </summary>
        /// <returns></returns>
        bool NeedInitializeClient()
        {
            return this.client == null ||
                this.client.State == System.ServiceModel.CommunicationState.Closed ||
                this.client.State == System.ServiceModel.CommunicationState.Faulted;
        }
        /// <summary>
        /// 初始化代理
        /// </summary>
        void InitializeClient()
        {
            // 使用默认的 Binding 和 EndpointAddress 初始化，在实际项目应使用 
            // new LoginProxy.LoginServiceClient(binding,remoteAddress)
            this.client = new LoginProxy.LoginServiceClient();
            
            this.client.GenerateValidationCodeCompleted += (sender, e) =>
            {
                if (e.Error == null)
                {
                    this.validationModel.GivenCode = e.Result;
                }
                else
                {
                    // 处理异常
                    MessageBox.Show(e.Error.Message);
                }
            };

            this.client.LoginCompleted += (sender, e) =>
            {
                if (e.Error == null)
                {
                    if (e.Result == 1)
                    {
                        // 登录成功
                        MessageBox.Show("登录成功");
                    }
                    else if (e.Result == 0)
                    {
                        // 用户名或密码错误
                        MessageBox.Show("用户名或密码错误");
                    }
                    else if (e.Result == 4)
                    {
                        // 校验码失效
                        MessageBox.Show("校验码失效");
                    }
                }
                else
                {
                    // 处理异常
                    MessageBox.Show(e.Error.Message);
                }
            };
        }
    }
}
