﻿using System;
using System.ComponentModel.DataAnnotations;
namespace MVVMTutorial.Web.Models
{
    /// <summary>
    /// 校验码class，这是一个临时的class，在MVVM方案中，这个class不存在
    /// </summary>
    [System.Diagnostics.DebuggerStepThroughAttribute()]
    public class ValidationModel : System.ComponentModel.INotifyPropertyChanged
    {
        private string CodeField;

        private string GivenCodeField;

        [Required]
        [StringLength(4, MinimumLength = 4)]
        [Display(Name="校验码", Description = "不区分大小写")]
        [RegularExpression("^[a-zA-Z0-9]*$", ErrorMessage = "只能输入字母、数字")]
        public string Code
        {
            get
            {
                return this.CodeField;
            }
            set
            {
                if ((object.ReferenceEquals(this.CodeField, value) != true))
                {
                    this.ValidateProperty("Code", value);
                    if (!object.Equals(value, this.GivenCodeField))
                    {
                        throw new NotSupportedException("请按照给定校验码输入");
                    }
                    this.CodeField = value;
                    this.RaisePropertyChanged("Code");
                }
            }
        }
        public string GivenCode
        {
            get
            {
                return this.GivenCodeField;
            }
            set
            {
                if ((object.ReferenceEquals(this.GivenCodeField, value) != true))
                {
                    this.GivenCodeField = value;
                    this.RaisePropertyChanged("GivenCode");
                }
            }
        }

        protected void ValidateProperty(string memberName, object value)
        {
            Validator.ValidateProperty(value, new ValidationContext(this, null, null) { MemberName = memberName });
        }

        public event System.ComponentModel.PropertyChangedEventHandler PropertyChanged;

        protected void RaisePropertyChanged(string propertyName)
        {
            System.ComponentModel.PropertyChangedEventHandler propertyChanged = this.PropertyChanged;
            if ((propertyChanged != null))
            {
                propertyChanged(this, new System.ComponentModel.PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
